@@ -208,7 +208,10 @@ else
   run_with_docker
 fi
 
-if  [ $(diff ${TEMP_CSV_FILE_PATH} ${CSV_FILE_PATH} | grep '[<>]' | wc -l) == 2 ] && \
+echo "Checking CSV diff"
+diff ${TEMP_CSV_FILE_PATH} ${CSV_FILE_PATH} || :
+
+if  [ $(diff ${TEMP_CSV_FILE_PATH} ${CSV_FILE_PATH} | grep '^[<>]' | wc -l) == 2 ] && \
     [ "$(diff ${TEMP_CSV_FILE_PATH} ${CSV_FILE_PATH} | grep -e '<*createdAt:')" != "" ]
 then
     echo "The CSV has not changed"
